
IO functions
----------------------

.. autosummary::

    bioconvert.io.maf
    bioconvert.io.scf


.. automodule:: bioconvert.io.scf
    :members:
    :synopsis:

.. automodule:: bioconvert.io.maf
    :members:
    :synopsis:


